@@ -4,7 +4,6 @@ use super::io::StdFileResource;
 use super::utils::into_string;
 use crate::fs_util::canonicalize_path;
 use crate::permissions::Permissions;
-use deno_core::error::bad_resource_id;
 use deno_core::error::custom_error;
 use deno_core::error::type_error;
 use deno_core::error::AnyError;
@@ -24,11 +23,16 @@ use serde::Serialize;
 use std::borrow::Cow;
 use std::cell::RefCell;
 use std::convert::From;
-use std::env::{current_dir, set_current_dir, temp_dir};
+use std::env::current_dir;
+use std::env::set_current_dir;
+use std::env::temp_dir;
 use std::io;
+use std::io::Error;
+use std::io::Seek;
+use std::io::SeekFrom;
 use std::io::Write;
-use std::io::{Error, Seek, SeekFrom};
-use std::path::{Path, PathBuf};
+use std::path::Path;
+use std::path::PathBuf;
 use std::rc::Rc;
 use std::time::SystemTime;
 use std::time::UNIX_EPOCH;
@@ -311,11 +315,8 @@ fn seek_helper(args: SeekArgs) -> Result<(u32, SeekFrom), AnyError> {
 #[op]
 fn op_seek_sync(state: &mut OpState, args: SeekArgs) -> Result<u64, AnyError> {
     let (rid, seek_from) = seek_helper(args)?;
-    let pos = StdFileResource::with(state, rid, |r| match r {
-        Ok(std_file) => std_file.seek(seek_from).map_err(AnyError::from),
-        Err(_) => Err(type_error(
-            "cannot seek on this type of resource".to_string(),
-        )),
+    let pos = StdFileResource::with_file(state, rid, |std_file| {
+        std_file.seek(seek_from).map_err(AnyError::from)
     })?;
     Ok(pos)
 }
@@ -329,15 +330,10 @@ async fn op_seek_async(state: Rc<RefCell<OpState>>, args: SeekArgs) -> Result<u6
         .resource_table
         .get::<StdFileResource>(rid)?;
 
-    if resource.fs_file.is_none() {
-        return Err(bad_resource_id());
-    }
-
-    let fs_file = resource.fs_file.as_ref().unwrap();
-    let std_file = fs_file.0.as_ref().unwrap().clone();
+    let std_file = resource.std_file();
 
     tokio::task::spawn_blocking(move || {
-        let mut std_file = std_file.lock().unwrap();
+        let mut std_file = std_file.lock();
         std_file.seek(seek_from)
     })
     .await?
@@ -346,9 +342,8 @@ async fn op_seek_async(state: Rc<RefCell<OpState>>, args: SeekArgs) -> Result<u6
 
 #[op]
 fn op_fdatasync_sync(state: &mut OpState, rid: ResourceId) -> Result<(), AnyError> {
-    StdFileResource::with(state, rid, |r| match r {
-        Ok(std_file) => std_file.sync_data().map_err(AnyError::from),
-        Err(_) => Err(type_error("cannot sync this type of resource".to_string())),
+    StdFileResource::with_file(state, rid, |std_file| {
+        std_file.sync_data().map_err(AnyError::from)
     })?;
     Ok(())
 }
@@ -360,15 +355,10 @@ async fn op_fdatasync_async(state: Rc<RefCell<OpState>>, rid: ResourceId) -> Res
         .resource_table
         .get::<StdFileResource>(rid)?;
 
-    if resource.fs_file.is_none() {
-        return Err(bad_resource_id());
-    }
-
-    let fs_file = resource.fs_file.as_ref().unwrap();
-    let std_file = fs_file.0.as_ref().unwrap().clone();
+    let std_file = resource.std_file();
 
     tokio::task::spawn_blocking(move || {
-        let std_file = std_file.lock().unwrap();
+        let std_file = std_file.lock();
         std_file.sync_data()
     })
     .await?
@@ -377,9 +367,8 @@ async fn op_fdatasync_async(state: Rc<RefCell<OpState>>, rid: ResourceId) -> Res
 
 #[op]
 fn op_fsync_sync(state: &mut OpState, rid: ResourceId) -> Result<(), AnyError> {
-    StdFileResource::with(state, rid, |r| match r {
-        Ok(std_file) => std_file.sync_all().map_err(AnyError::from),
-        Err(_) => Err(type_error("cannot sync this type of resource".to_string())),
+    StdFileResource::with_file(state, rid, |std_file| {
+        std_file.sync_all().map_err(AnyError::from)
     })?;
     Ok(())
 }
@@ -391,15 +380,10 @@ async fn op_fsync_async(state: Rc<RefCell<OpState>>, rid: ResourceId) -> Result<
         .resource_table
         .get::<StdFileResource>(rid)?;
 
-    if resource.fs_file.is_none() {
-        return Err(bad_resource_id());
-    }
-
-    let fs_file = resource.fs_file.as_ref().unwrap();
-    let std_file = fs_file.0.as_ref().unwrap().clone();
+    let std_file = resource.std_file();
 
     tokio::task::spawn_blocking(move || {
-        let std_file = std_file.lock().unwrap();
+        let std_file = std_file.lock();
         std_file.sync_all()
     })
     .await?
@@ -408,9 +392,8 @@ async fn op_fsync_async(state: Rc<RefCell<OpState>>, rid: ResourceId) -> Result<
 
 #[op]
 fn op_fstat_sync(state: &mut OpState, rid: ResourceId) -> Result<FsStat, AnyError> {
-    let metadata = StdFileResource::with(state, rid, |r| match r {
-        Ok(std_file) => std_file.metadata().map_err(AnyError::from),
-        Err(_) => Err(type_error("cannot stat this type of resource".to_string())),
+    let metadata = StdFileResource::with_file(state, rid, |std_file| {
+        std_file.metadata().map_err(AnyError::from)
     })?;
     Ok(get_stat(metadata))
 }
@@ -422,15 +405,10 @@ async fn op_fstat_async(state: Rc<RefCell<OpState>>, rid: ResourceId) -> Result<
         .resource_table
         .get::<StdFileResource>(rid)?;
 
-    if resource.fs_file.is_none() {
-        return Err(bad_resource_id());
-    }
-
-    let fs_file = resource.fs_file.as_ref().unwrap();
-    let std_file = fs_file.0.as_ref().unwrap().clone();
+    let std_file = resource.std_file();
 
     let metadata = tokio::task::spawn_blocking(move || {
-        let std_file = std_file.lock().unwrap();
+        let std_file = std_file.lock();
         std_file.metadata()
     })
     .await?
@@ -443,16 +421,13 @@ fn op_flock_sync(state: &mut OpState, rid: ResourceId, exclusive: bool) -> Resul
     use fs3::FileExt;
     super::check_unstable(state, "Deno.flockSync");
 
-    StdFileResource::with(state, rid, |r| match r {
-        Ok(std_file) => {
-            if exclusive {
-                std_file.lock_exclusive()?;
-            } else {
-                std_file.lock_shared()?;
-            }
-            Ok(())
+    StdFileResource::with_file(state, rid, |std_file| {
+        if exclusive {
+            std_file.lock_exclusive()?;
+        } else {
+            std_file.lock_shared()?;
         }
-        Err(_) => Err(type_error("cannot lock this type of resource".to_string())),
+        Ok(())
     })
 }
 
@@ -470,15 +445,10 @@ async fn op_flock_async(
         .resource_table
         .get::<StdFileResource>(rid)?;
 
-    if resource.fs_file.is_none() {
-        return Err(bad_resource_id());
-    }
-
-    let fs_file = resource.fs_file.as_ref().unwrap();
-    let std_file = fs_file.0.as_ref().unwrap().clone();
+    let std_file = resource.std_file();
 
     tokio::task::spawn_blocking(move || -> Result<(), AnyError> {
-        let std_file = std_file.lock().unwrap();
+        let std_file = std_file.lock();
         if exclusive {
             std_file.lock_exclusive()?;
         } else {
@@ -494,12 +464,9 @@ fn op_funlock_sync(state: &mut OpState, rid: ResourceId) -> Result<(), AnyError>
     use fs3::FileExt;
     super::check_unstable(state, "Deno.funlockSync");
 
-    StdFileResource::with(state, rid, |r| match r {
-        Ok(std_file) => {
-            std_file.unlock()?;
-            Ok(())
-        }
-        Err(_) => Err(type_error("cannot lock this type of resource".to_string())),
+    StdFileResource::with_file(state, rid, |std_file| {
+        std_file.unlock()?;
+        Ok(())
     })
 }
 
@@ -513,15 +480,10 @@ async fn op_funlock_async(state: Rc<RefCell<OpState>>, rid: ResourceId) -> Resul
         .resource_table
         .get::<StdFileResource>(rid)?;
 
-    if resource.fs_file.is_none() {
-        return Err(bad_resource_id());
-    }
-
-    let fs_file = resource.fs_file.as_ref().unwrap();
-    let std_file = fs_file.0.as_ref().unwrap().clone();
+    let std_file = resource.std_file();
 
     tokio::task::spawn_blocking(move || -> Result<(), AnyError> {
-        let std_file = std_file.lock().unwrap();
+        let std_file = std_file.lock();
         std_file.unlock()?;
         Ok(())
     })
@@ -1516,9 +1478,8 @@ pub struct FtruncateArgs {
 fn op_ftruncate_sync(state: &mut OpState, args: FtruncateArgs) -> Result<(), AnyError> {
     let rid = args.rid;
     let len = args.len as u64;
-    StdFileResource::with(state, rid, |r| match r {
-        Ok(std_file) => std_file.set_len(len).map_err(AnyError::from),
-        Err(_) => Err(type_error("cannot truncate this type of resource")),
+    StdFileResource::with_file(state, rid, |std_file| {
+        std_file.set_len(len).map_err(AnyError::from)
     })?;
     Ok(())
 }
@@ -1536,15 +1497,10 @@ async fn op_ftruncate_async(
         .resource_table
         .get::<StdFileResource>(rid)?;
 
-    if resource.fs_file.is_none() {
-        return Err(bad_resource_id());
-    }
-
-    let fs_file = resource.fs_file.as_ref().unwrap();
-    let std_file = fs_file.0.as_ref().unwrap().clone();
+    let std_file = resource.std_file();
 
     tokio::task::spawn_blocking(move || {
-        let std_file = std_file.lock().unwrap();
+        let std_file = std_file.lock();
         std_file.set_len(len)
     })
     .await?
@@ -1798,12 +1754,8 @@ fn op_futime_sync(state: &mut OpState, args: FutimeArgs) -> Result<(), AnyError>
     let atime = filetime::FileTime::from_unix_time(args.atime.0, args.atime.1);
     let mtime = filetime::FileTime::from_unix_time(args.mtime.0, args.mtime.1);
 
-    StdFileResource::with(state, rid, |r| match r {
-        Ok(std_file) => filetime::set_file_handle_times(std_file, Some(atime), Some(mtime))
-            .map_err(AnyError::from),
-        Err(_) => Err(type_error(
-            "cannot futime on this type of resource".to_string(),
-        )),
+    StdFileResource::with_file(state, rid, |std_file| {
+        filetime::set_file_handle_times(std_file, Some(atime), Some(mtime)).map_err(AnyError::from)
     })?;
 
     Ok(())
@@ -1821,14 +1773,9 @@ async fn op_futime_async(state: Rc<RefCell<OpState>>, args: FutimeArgs) -> Resul
         .resource_table
         .get::<StdFileResource>(rid)?;
 
-    if resource.fs_file.is_none() {
-        return Err(bad_resource_id());
-    }
-
-    let fs_file = resource.fs_file.as_ref().unwrap();
-    let std_file = fs_file.0.as_ref().unwrap().clone();
+    let std_file = resource.std_file();
     tokio::task::spawn_blocking(move || {
-        let std_file = std_file.lock().unwrap();
+        let std_file = std_file.lock();
         filetime::set_file_handle_times(&std_file, Some(atime), Some(mtime))?;
         Ok(())
     })
