@@ -1,9 +1,6 @@
 // Copyright 2018-2022 the Deno authors. All rights reserved. MIT license.
 
 use super::io::StdFileResource;
-use deno_core::error::bad_resource_id;
-use deno_core::error::not_supported;
-use deno_core::error::resource_unavailable;
 use deno_core::error::AnyError;
 use deno_core::op;
 use deno_core::Extension;
@@ -85,23 +82,12 @@ fn op_set_raw(state: &mut OpState, args: SetRawArgs) -> Result<(), AnyError> {
         let resource = state.resource_table.get::<StdFileResource>(rid)?;
 
         if cbreak {
-            return Err(not_supported());
+            return Err(deno_core::error::not_supported());
         }
 
-        if resource.fs_file.is_none() {
-            return Err(bad_resource_id());
-        }
-
-        let handle_result = if let Some((fs_file, _)) = &resource.fs_file {
-            let file = fs_file.as_ref().unwrap().clone();
-            let std_file = file.lock().unwrap();
-            let raw_handle = std_file.as_raw_handle();
-            Ok(raw_handle)
-        } else {
-            Err(resource_unavailable())
-        };
-
-        let handle = handle_result?;
+        let std_file = resource.std_file();
+        let std_file = std_file.lock(); // hold the lock
+        let handle = std_file.as_raw_handle();
 
         if handle == handleapi::INVALID_HANDLE_VALUE {
             return Err(Error::last_os_error().into());
@@ -128,19 +114,10 @@ fn op_set_raw(state: &mut OpState, args: SetRawArgs) -> Result<(), AnyError> {
         use std::os::unix::io::AsRawFd;
 
         let resource = state.resource_table.get::<StdFileResource>(rid)?;
-
-        if resource.fs_file.is_none() {
-            return Err(not_supported());
-        }
-
-        let (fs_file, meta) = resource.fs_file.as_ref().ok_or_else(resource_unavailable)?;
-
-        if fs_file.is_none() {
-            return Err(resource_unavailable());
-        }
-
-        let raw_fd = fs_file.as_ref().unwrap().lock().unwrap().as_raw_fd();
-        let maybe_tty_mode = &mut meta.as_ref().unwrap().borrow_mut().tty.mode;
+        let std_file = resource.std_file();
+        let raw_fd = std_file.lock().as_raw_fd();
+        let mut meta_data = resource.metadata_mut();
+        let maybe_tty_mode = &mut meta_data.tty.mode;
 
         if is_raw {
             if maybe_tty_mode.is_none() {
@@ -181,25 +158,23 @@ fn op_set_raw(state: &mut OpState, args: SetRawArgs) -> Result<(), AnyError> {
 
 #[op]
 fn op_isatty(state: &mut OpState, rid: ResourceId) -> Result<bool, AnyError> {
-    let isatty: bool = StdFileResource::with(state, rid, move |r| match r {
-        Ok(std_file) => {
-            #[cfg(windows)]
-            {
-                use winapi::um::consoleapi;
+    let isatty: bool = StdFileResource::with_file(state, rid, move |std_file| {
+        #[cfg(windows)]
+        {
+            use winapi::shared::minwindef::FALSE;
+            use winapi::um::consoleapi;
 
-                let handle = get_windows_handle(std_file)?;
-                let mut test_mode: DWORD = 0;
-                // If I cannot get mode out of console, it is not a console.
-                Ok(unsafe { consoleapi::GetConsoleMode(handle, &mut test_mode) != 0 })
-            }
-            #[cfg(unix)]
-            {
-                use std::os::unix::io::AsRawFd;
-                let raw_fd = std_file.as_raw_fd();
-                Ok(unsafe { libc::isatty(raw_fd as libc::c_int) == 1 })
-            }
+            let handle = get_windows_handle(std_file)?;
+            let mut test_mode: DWORD = 0;
+            // If I cannot get mode out of console, it is not a console.
+            Ok(unsafe { consoleapi::GetConsoleMode(handle, &mut test_mode) != FALSE })
+        }
+        #[cfg(unix)]
+        {
+            use std::os::unix::io::AsRawFd;
+            let raw_fd = std_file.as_raw_fd();
+            Ok(unsafe { libc::isatty(raw_fd as libc::c_int) == 1 })
         }
-        _ => Ok(false),
     })?;
     Ok(isatty)
 }
@@ -214,48 +189,45 @@ struct ConsoleSize {
 fn op_console_size(state: &mut OpState, rid: ResourceId) -> Result<ConsoleSize, AnyError> {
     super::check_unstable(state, "Deno.consoleSize");
 
-    let size = StdFileResource::with(state, rid, move |r| match r {
-        Ok(std_file) => {
-            #[cfg(windows)]
-            {
-                use std::os::windows::io::AsRawHandle;
-                let handle = std_file.as_raw_handle();
+    let size = StdFileResource::with_file(state, rid, move |std_file| {
+        #[cfg(windows)]
+        {
+            use std::os::windows::io::AsRawHandle;
+            let handle = std_file.as_raw_handle();
 
-                unsafe {
-                    let mut bufinfo: winapi::um::wincon::CONSOLE_SCREEN_BUFFER_INFO =
-                        std::mem::zeroed();
+            unsafe {
+                let mut bufinfo: winapi::um::wincon::CONSOLE_SCREEN_BUFFER_INFO =
+                    std::mem::zeroed();
 
-                    if winapi::um::wincon::GetConsoleScreenBufferInfo(handle, &mut bufinfo) == 0 {
-                        return Err(Error::last_os_error().into());
-                    }
-
-                    Ok(ConsoleSize {
-                        columns: bufinfo.dwSize.X as u32,
-                        rows: bufinfo.dwSize.Y as u32,
-                    })
+                if winapi::um::wincon::GetConsoleScreenBufferInfo(handle, &mut bufinfo) == 0 {
+                    return Err(Error::last_os_error().into());
                 }
-            }
 
-            #[cfg(unix)]
-            {
-                use std::os::unix::io::AsRawFd;
+                Ok(ConsoleSize {
+                    columns: bufinfo.dwSize.X as u32,
+                    rows: bufinfo.dwSize.Y as u32,
+                })
+            }
+        }
 
-                let fd = std_file.as_raw_fd();
-                unsafe {
-                    let mut size: libc::winsize = std::mem::zeroed();
-                    if libc::ioctl(fd, libc::TIOCGWINSZ, &mut size as *mut _) != 0 {
-                        return Err(Error::last_os_error().into());
-                    }
+        #[cfg(unix)]
+        {
+            use std::os::unix::io::AsRawFd;
 
-                    // TODO (caspervonb) return a tuple instead
-                    Ok(ConsoleSize {
-                        columns: size.ws_col as u32,
-                        rows: size.ws_row as u32,
-                    })
+            let fd = std_file.as_raw_fd();
+            unsafe {
+                let mut size: libc::winsize = std::mem::zeroed();
+                if libc::ioctl(fd, libc::TIOCGWINSZ, &mut size as *mut _) != 0 {
+                    return Err(Error::last_os_error().into());
                 }
+
+                // TODO (caspervonb) return a tuple instead
+                Ok(ConsoleSize {
+                    columns: size.ws_col as u32,
+                    rows: size.ws_row as u32,
+                })
             }
         }
-        Err(_) => Err(bad_resource_id()),
     })?;
 
     Ok(size)
